@@ -1,13 +1,15 @@
-#' @useDynLib later, .registration=TRUE
-#' @importFrom Rcpp evalCpp
+# nocov start
+# tested implicitly
 
-.onLoad <- function(...) {
+.onLoad <- function(libname, pkgname) {
   ensureInitialized()
   .globals$next_id <- 0L
   # Store a ref to the global loop so it doesn't get GC'd.
   .globals$global_loop <- create_loop(parent = NULL)
 }
 
+# nocov end
+
 .globals <- new.env(parent = emptyenv())
 # A registry of weak refs to loop handle objects. Given an ID number, we can
 # get the corresponding loop handle. We use weak refs because we don't want
